==> openjdk13-13.0.13_0+release+server.darwin_24.x86_64.tbz2: jdk.localedata/sun/util/resources/cldr/ext/LocaleNames_rw.java <==
/*
 * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class LocaleNames_rw extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "MK", "Masedoniya y'Amajyaruguru" },
            { "RW", "U Rwanda" },
            { "TO", "Tonga" },
            { "af", "Ikinyafurikaneri" },
            { "am", "Inyamuhariki" },
            { "ar", "Icyarabu" },
            { "as", "Icyasamizi" },
            { "az", "Inyazeribayijani" },
            { "be", "Ikibelarusiya" },
            { "bg", "Urunyabuligariya" },
            { "bn", "Ikibengali" },
            { "br", "Inyebiritoni" },
            { "bs", "Inyebosiniya" },
            { "ca", "Igikatalani" },
            { "cs", "Igiceke" },
            { "cy", "Ikigaluwa" },
            { "da", "Ikidaninwa" },
            { "de", "Ikidage" },
            { "el", "Ikigereki" },
            { "en", "Icyongereza" },
            { "eo", "Icyesiperanto" },
            { "es", "Icyesipanyolo" },
            { "et", "Icyesitoniya" },
            { "eu", "Ikibasiki" },
            { "fa", "Inyeperisi" },
            { "fi", "Igifinilande" },
            { "fo", "Inyefaroyizi" },
            { "fr", "Igifaransa" },
            { "fy", "Igifiriziyani" },
            { "ga", "Ikirilandi" },
            { "gd", "Ikigaluwa cy\u2019Igisweduwa" },
            { "gl", "Ikigalisiya" },
            { "gn", "Inyaguwarani" },
            { "gu", "Inyegujarati" },
            { "he", "Igiheburayo" },
            { "hi", "Igihindi" },
            { "hr", "Igikorowasiya" },
            { "hu", "Igihongiriya" },
            { "hy", "Ikinyarumeniya" },
            { "ia", "Ururimi Gahuzamiryango" },
            { "id", "Ikinyendoziya" },
            { "ie", "Uruhuzandimi" },
            { "is", "Igisilande" },
            { "it", "Igitaliyani" },
            { "ja", "Ikiyapani" },
            { "jv", "Inyejava" },
            { "ka", "Inyejeworujiya" },
            { "km", "Igikambodiya" },
            { "kn", "Igikanada" },
            { "ko", "Igikoreya" },
            { "ku", "Inyekuridishi" },
            { "ky", "Inkerigizi" },
            { "la", "Ikilatini" },
            { "ln", "Ilingala" },
            { "lo", "Ikilawotiyani" },
            { "lt", "Ikilituwaniya" },
            { "lv", "Ikinyaletoviyani" },
            { "mk", "Ikimasedoniya" },
            { "ml", "Ikimalayalami" },
            { "mn", "Ikimongoli" },
            { "mr", "Ikimarati" },
            { "ms", "Ikimalayi" },
            { "mt", "Ikimaliteze" },
            { "ne", "Ikinepali" },
            { "nl", "Ikinerilande" },
            { "nn", "Inyenoruveji (Nyonorusiki)" },
            { "no", "Ikinoruveji" },
            { "oc", "Inyogusitani" },
            { "or", "Inyoriya" },
            { "pa", "Igipunjabi" },
            { "pl", "Igipolone" },
            { "ps", "Impashito" },
            { "pt", "Igiporutugali" },
            { "ro", "Ikinyarumaniya" },
            { "ru", "Ikirusiya" },
            { "rw", "Kinyarwanda" },
            { "sa", "Igisansikiri" },
            { "sd", "Igisindi" },
            { "sh", "Inyeseribiya na Korowasiya" },
            { "si", "Inyesimpaleze" },
            { "sk", "Igisilovaki" },
            { "sl", "Ikinyasiloveniya" },
            { "so", "Igisomali" },
            { "sq", "Icyalubaniya" },
            { "sr", "Igiseribe" },
            { "st", "Inyesesoto" },
            { "su", "Inyesudani" },
            { "sv", "Igisuweduwa" },
            { "sw", "Igiswahili" },
            { "ta", "Igitamili" },
            { "te", "Igitelugu" },
            { "th", "Igitayi" },
            { "ti", "Inyatigirinya" },
            { "tk", "Inyeturukimeni" },
            { "tr", "Igiturukiya" },
            { "tw", "Inyetuwi" },
            { "ug", "Ikiwiguri" },
            { "uk", "Ikinyayukereni" },
            { "ur", "Inyeyurudu" },
            { "uz", "Inyeyuzubeki" },
            { "vi", "Ikinyaviyetinamu" },
            { "xh", "Inyehawusa" },
            { "yi", "Inyeyidishi" },
            { "zu", "Inyezulu" },
            { "fil", "Ikinyafilipine" },
            { "tlh", "Inyekilingoni" },
            { "pt_BR", "Inyeporutigali (Brezili)" },
            { "pt_PT", "Inyeporutigali (Igiporutigali)" },
        };
        return data;
    }
}

==> openjdk15-15.0.9_0+release+server.darwin_24.x86_64.tbz2: jdk.localedata/sun/util/resources/cldr/ext/LocaleNames_rw.java <==
/*
 * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class LocaleNames_rw extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "MK", "Masedoniya y\u2019Amajyaruguru" },
            { "RW", "U Rwanda" },
            { "TO", "Tonga" },
            { "af", "Ikinyafurikaneri" },
            { "am", "Inyamuhariki" },
            { "ar", "Icyarabu" },
            { "as", "Icyasamizi" },
            { "az", "Inyazeribayijani" },
            { "be", "Ikibelarusiya" },
            { "bg", "Urunyabuligariya" },
            { "bn", "Ikibengali" },
            { "br", "Inyebiritoni" },
            { "bs", "Inyebosiniya" },
            { "ca", "Igikatalani" },
            { "cs", "Igiceke" },
            { "cy", "Ikigaluwa" },
            { "da", "Ikidaninwa" },
            { "de", "Ikidage" },
            { "el", "Ikigereki" },
            { "en", "Icyongereza" },
            { "eo", "Icyesiperanto" },
            { "es", "Icyesipanyolo" },
            { "et", "Icyesitoniya" },
            { "eu", "Ikibasiki" },
            { "fa", "Inyeperisi" },
            { "fi", "Igifinilande" },
            { "fo", "Inyefaroyizi" },
            { "fr", "Igifaransa" },
            { "fy", "Igifiriziyani" },
            { "ga", "Ikirilandi" },
            { "gd", "Ikigaluwa cy\u2019Igisweduwa" },
            { "gl", "Ikigalisiya" },
            { "gn", "Inyaguwarani" },
            { "gu", "Inyegujarati" },
            { "he", "Igiheburayo" },
            { "hi", "Igihindi" },
            { "hr", "Igikorowasiya" },
            { "hu", "Igihongiriya" },
            { "hy", "Ikinyarumeniya" },
            { "ia", "Ururimi Gahuzamiryango" },
            { "id", "Ikinyendoziya" },
            { "ie", "Uruhuzandimi" },
            { "is", "Igisilande" },
            { "it", "Igitaliyani" },
            { "ja", "Ikiyapani" },
            { "jv", "Inyejava" },
            { "ka", "Inyejeworujiya" },
            { "km", "Igikambodiya" },
            { "kn", "Igikanada" },
            { "ko", "Igikoreya" },
            { "ku", "Inyekuridishi" },
            { "ky", "Inkerigizi" },
            { "la", "Ikilatini" },
            { "ln", "Ilingala" },
            { "lo", "Ikilawotiyani" },
            { "lt", "Ikilituwaniya" },
            { "lv", "Ikinyaletoviyani" },
            { "mk", "Ikimasedoniya" },
            { "ml", "Ikimalayalami" },
            { "mn", "Ikimongoli" },
            { "mr", "Ikimarati" },
            { "ms", "Ikimalayi" },
            { "mt", "Ikimaliteze" },
            { "ne", "Ikinepali" },
            { "nl", "Ikinerilande" },
            { "nn", "Inyenoruveji (Nyonorusiki)" },
            { "no", "Ikinoruveji" },
            { "oc", "Inyogusitani" },
            { "or", "Inyoriya" },
            { "pa", "Igipunjabi" },
            { "pl", "Igipolone" },
            { "ps", "Impashito" },
            { "pt", "Igiporutugali" },
            { "ro", "Ikinyarumaniya" },
            { "ru", "Ikirusiya" },
            { "rw", "Kinyarwanda" },
            { "sa", "Igisansikiri" },
            { "sd", "Igisindi" },
            { "sh", "Inyeseribiya na Korowasiya" },
            { "si", "Inyesimpaleze" },
            { "sk", "Igisilovaki" },
            { "sl", "Ikinyasiloveniya" },
            { "so", "Igisomali" },
            { "sq", "Icyalubaniya" },
            { "sr", "Igiseribe" },
            { "st", "Inyesesoto" },
            { "su", "Inyesudani" },
            { "sv", "Igisuweduwa" },
            { "sw", "Igiswahili" },
            { "ta", "Igitamili" },
            { "te", "Igitelugu" },
            { "th", "Igitayi" },
            { "ti", "Inyatigirinya" },
            { "tk", "Inyeturukimeni" },
            { "tr", "Igiturukiya" },
            { "tw", "Inyetuwi" },
            { "ug", "Ikiwiguri" },
            { "uk", "Ikinyayukereni" },
            { "ur", "Inyeyurudu" },
            { "uz", "Inyeyuzubeki" },
            { "vi", "Ikinyaviyetinamu" },
            { "xh", "Inyehawusa" },
            { "yi", "Inyeyidishi" },
            { "zu", "Inyezulu" },
            { "fil", "Ikinyafilipine" },
            { "tlh", "Inyekilingoni" },
            { "pt_BR", "Inyeporutigali (Brezili)" },
            { "pt_PT", "Inyeporutigali (Igiporutigali)" },
        };
        return data;
    }
}
